import sys

from workspace import command_build, command_cmake, command_help, command_install, command_pull, command_status

commands = [command_build, command_cmake, command_help, command_install, command_pull, command_status]
